
From: Peter Osterlund <petero2@telia.com>

Remove some redundant BUG_ON() statements in pktcdvd and move one run-time
check to compile-time.

Signed-off-by: Peter Osterlund <petero2@telia.com>
Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 drivers/block/pktcdvd.c |    9 +++------
 include/linux/pktcdvd.h |    3 +++
 2 files changed, 6 insertions(+), 6 deletions(-)

diff -puN drivers/block/pktcdvd.c~pktcdvd-bug_on-cleanups drivers/block/pktcdvd.c
--- devel/drivers/block/pktcdvd.c~pktcdvd-bug_on-cleanups	2005-09-11 12:33:38.000000000 -0700
+++ devel-akpm/drivers/block/pktcdvd.c	2005-09-11 12:33:38.000000000 -0700
@@ -669,7 +669,6 @@ static void pkt_make_local_copy(struct p
 		}
 		offs += CD_FRAMESIZE;
 		if (offs >= PAGE_SIZE) {
-			BUG_ON(offs > PAGE_SIZE);
 			offs = 0;
 			p++;
 		}
@@ -804,10 +803,11 @@ static struct packet_data *pkt_get_packe
 			list_del_init(&pkt->list);
 			if (pkt->sector != zone)
 				pkt->cache_valid = 0;
-			break;
+			return pkt;
 		}
 	}
-	return pkt;
+	BUG();
+	return NULL;
 }
 
 static void pkt_put_packet_data(struct pktcdvd_device *pd, struct packet_data *pkt)
@@ -951,7 +951,6 @@ try_next_bio:
 	}
 
 	pkt = pkt_get_packet_data(pd, zone);
-	BUG_ON(!pkt);
 
 	pd->current_sector = zone + pd->settings.size;
 	pkt->sector = zone;
@@ -2211,7 +2210,6 @@ static int pkt_make_request(request_queu
 	 * No matching packet found. Store the bio in the work queue.
 	 */
 	node = mempool_alloc(pd->rb_pool, GFP_NOIO);
-	BUG_ON(!node);
 	node->bio = bio;
 	spin_lock(&pd->lock);
 	BUG_ON(pd->bio_queue_size < 0);
@@ -2419,7 +2417,6 @@ static int pkt_ioctl(struct inode *inode
 	struct pktcdvd_device *pd = inode->i_bdev->bd_disk->private_data;
 
 	VPRINTK("pkt_ioctl: cmd %x, dev %d:%d\n", cmd, imajor(inode), iminor(inode));
-	BUG_ON(!pd);
 
 	switch (cmd) {
 	/*
diff -puN include/linux/pktcdvd.h~pktcdvd-bug_on-cleanups include/linux/pktcdvd.h
--- devel/include/linux/pktcdvd.h~pktcdvd-bug_on-cleanups	2005-09-11 12:33:38.000000000 -0700
+++ devel-akpm/include/linux/pktcdvd.h	2005-09-11 12:33:38.000000000 -0700
@@ -166,6 +166,9 @@ struct packet_iosched
 /*
  * 32 buffers of 2048 bytes
  */
+#if (PAGE_SIZE % CD_FRAMESIZE) != 0
+#error "PAGE_SIZE must be a multiple of CD_FRAMESIZE"
+#endif
 #define PACKET_MAX_SIZE		32
 #define PAGES_PER_PACKET	(PACKET_MAX_SIZE * CD_FRAMESIZE / PAGE_SIZE)
 #define PACKET_MAX_SECTORS	(PACKET_MAX_SIZE * CD_FRAMESIZE >> 9)
_
